@@ -2,7 +2,7 @@
 #
 # a graphical debugger for compiled CHICKEN programs
 #
-# Copyright (c) 2015-2017, The CHICKEN Team
+# Copyright (c) 2015-2020, The CHICKEN Team
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
@@ -27,19 +27,18 @@
 
 
 set version 0
-set protocol_version 0
+set protocol_version 1
 set debugger_port 9999
 
-set events(0) call
-set events(1) assign
-set events(2) gc
-set events(3) entry
-set events(4) signal
-set events(5) connect
-set events(6) listen
-set events(7) interrupted
+set events(1) call
+set events(2) assign
+set events(3) gc
+set events(4) entry
+set events(5) signal
+set events(6) connect
+set events(7) listen
+set events(8) interrupted
 
-set reply(UNUSED) 0
 set reply(SETMASK) 1
 set reply(TERMINATE) 2
 set reply(CONTINUE) 3
@@ -82,8 +81,8 @@ set typecode(43) TAGGED_POINTER
 set typecode(77) LAMBDA_INFO
 set typecode(15) BUCKET
 
-set EXEC_EVENT_MASK 16; # signal
-set STEP_EVENT_MASK 27; # call, entry, assign, signal
+set EXEC_EVENT_MASK 32; # signal
+set STEP_EVENT_MASK 54; # call, entry, assign, signal
 
 set membar_height 50
 set value_cutoff_limit 200; # must be lower than limit in dbg-stub.c
@@ -700,7 +699,17 @@ proc RunProcess {{prg ""}} {
 
     if {$program_name == ""} return
 
-    lappend search_path [file dirname [lindex $program_name 0]]
+    set args [lassign $program_name prgfname]
+    set prgfname [file normalize $prgfname]
+
+    if {![file exists $prgfname]} {
+        .t configure -state normal
+        .t insert end "Could not start program:\n\nfile `$prgfname' does not exist"
+        .t see end
+        .t configure -state disabled
+    }
+
+    lappend search_path [file dirname $prgfname]
     set reply_queue {}
     set data_queue {}
     set bp_queue {}
@@ -728,8 +737,11 @@ proc RunProcess {{prg ""}} {
         .data.t delete [.data.t children $arguments_item_id]
     }
 
-    if {[catch {eval exec $program_name <@ stdin >@ stdout 2>@ stderr &} result]} {
+    if {[catch {eval exec $prgfname {*}$args <@ stdin >@ stdout 2>@ stderr &} result]} {
+        .t configure -state normal
         .t insert end "Could not start program:\n\n$result"
+        .t see end
+        .t configure -state disabled
     } else {
         set process_id $result
     }
@@ -771,8 +783,10 @@ proc ProcessInput {} {
 
 
 proc ProcessLine {line} {
-    if {[regexp {^\((\d+)\s+"([^"]*)"\s+"([^"]*)"\s+"([^"]*)"\)$} $line _ evt loc val \
-        cloc]} {
+    if {[regexp {^\((\d+)\s+([^\s]*)\s+([^\s]*)\s+([^)]*)\)$} $line _ evt loc val cloc]} {
+        set val [ProcessString $val]
+        set loc [ProcessString $loc]
+        set cloc [ProcessString $cloc]
         ProcessEvent $evt $loc $val $cloc
     } elseif {[regexp {^\(\*\s*(.*)\)$} $line _ data]} {
         ProcessData $data
@@ -1466,6 +1480,15 @@ proc InsertDebugInfo {index event args} {
     return 0
 }
 
+proc ProcessString {str} {
+    if {$str == "#f"} {
+        return ""
+    } elseif {[regexp {^"(.*)"$} $str _ strip]} {
+        return $strip
+    } else {
+        return $str
+    }
+}
 
 proc FetchEventListReply {} {
     global file_list reply_queue data_queue
@@ -1476,8 +1499,9 @@ proc FetchEventListReply {} {
 
 
 proc EventInfoData {data} {
-    if {[regexp {(\d+)\s+(\d+)\s+"([^"]*)"\s+"([^"]*)"$} $data _ index event \
-        loc val]} {
+    if {[regexp {(\d+)\s+(\d+)\s+([^\s]*)\s+(.*)$} $data _ index event loc val]} {
+        set loc [ProcessString $loc]
+        set val [ProcessString $val]
         InsertDebugInfo $index $event $loc $val
     } else {
         UpdateHeader "invalid event data: $data"
@@ -1886,8 +1910,6 @@ if {$program_name != ""} {
 # - setting breakpoints on yet unregistered (i.e. dynamically loaded) files
 #   is not possible - a file must be registered first
 # - check whether "listening" check works
-# - backport to chicken4
-#   - feature ("dbg-client")
 # - when retrieved data is wrong, clear queues
 # - must watched globals be mangled, when qualified? (GET_GLOBAL)
 # - dview: monospace font (needs tags, it seems)
